quantizationtools.PitchedQEvent
===============================

.. abjad-lineage:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent

.. autoclass:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.attachments
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.index
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.offset
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.pitches
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.storage_format
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__eq__
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__getstate__
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__lt__
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__ne__
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__repr__
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__setstate__

Bases
-----

- :py:class:`quantizationtools.QEvent <abjad.tools.quantizationtools.QEvent.QEvent.QEvent>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.attachments
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.pitches
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.storage_format
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__setstate__
   :noindex:
